dri-devel.lists.freedesktop.org archive mirror
 help / color / mirror / Atom feed
From: Gabriel Laskar <gabriel@lse.epita.fr>
To: David Airlie <airlied@linux.ie>,
	"open list:DRM DRIVERS" <dri-devel@lists.freedesktop.org>,
	"open list:ABI/API" <linux-api@vger.kernel.org>,
	open list <linux-kernel@vger.kernel.org>
Cc: Mikko Rapeli <mikko.rapeli@iki.fi>,
	Emil Velikov <emil.l.velikov@gmail.com>
Subject: [PATCH 01/20] drm: use __u{32, 64} instead of uint{32, 64}_t in virtgpu_drm.h
Date: Mon, 30 Nov 2015 15:10:39 +0100	[thread overview]
Message-ID: <1448892658-14256-2-git-send-email-gabriel@lse.epita.fr> (raw)
In-Reply-To: <1448892658-14256-1-git-send-email-gabriel@lse.epita.fr>

Signed-off-by: Gabriel Laskar <gabriel@lse.epita.fr>
CC: Emil Velikov <emil.l.velikov@gmail.com>
CC: Mikko Rapeli <mikko.rapeli@iki.fi>

---
 include/uapi/drm/virtgpu_drm.h | 98 +++++++++++++++++++++---------------------
 1 file changed, 49 insertions(+), 49 deletions(-)

diff --git a/include/uapi/drm/virtgpu_drm.h b/include/uapi/drm/virtgpu_drm.h
index fc9e2d6..4bcfbe6 100644
--- a/include/uapi/drm/virtgpu_drm.h
+++ b/include/uapi/drm/virtgpu_drm.h
@@ -30,7 +30,7 @@
 /* Please note that modifications to all structs defined here are
  * subject to backwards-compatibility constraints.
  *
  * Do not use pointers, use uint64_t instead for 32 bit / 64 bit user/kernel
  * compatibility Keep fields aligned to their size
  */
 
@@ -45,88 +45,88 @@
 #define DRM_VIRTGPU_GET_CAPS  0x09
 
 struct drm_virtgpu_map {
-	uint64_t offset; /* use for mmap system call */
-	uint32_t handle;
-	uint32_t pad;
+	__u64 offset; /* use for mmap system call */
+	__u32 handle;
+	__u32 pad;
 };
 
 struct drm_virtgpu_execbuffer {
-	uint32_t		flags;		/* for future use */
-	uint32_t size;
-	uint64_t command; /* void* */
-	uint64_t bo_handles;
-	uint32_t num_bo_handles;
-	uint32_t pad;
+	__u32		flags;		/* for future use */
+	__u32 size;
+	__u64 command; /* void* */
+	__u64 bo_handles;
+	__u32 num_bo_handles;
+	__u32 pad;
 };
 
 #define VIRTGPU_PARAM_3D_FEATURES 1 /* do we have 3D features in the hw */
 
 struct drm_virtgpu_getparam {
-	uint64_t param;
-	uint64_t value;
+	__u64 param;
+	__u64 value;
 };
 
 /* NO_BO flags? NO resource flag? */
 /* resource flag for y_0_top */
 struct drm_virtgpu_resource_create {
-	uint32_t target;
-	uint32_t format;
-	uint32_t bind;
-	uint32_t width;
-	uint32_t height;
-	uint32_t depth;
-	uint32_t array_size;
-	uint32_t last_level;
-	uint32_t nr_samples;
-	uint32_t flags;
-	uint32_t bo_handle; /* if this is set - recreate a new resource attached to this bo ? */
-	uint32_t res_handle;  /* returned by kernel */
-	uint32_t size;        /* validate transfer in the host */
-	uint32_t stride;      /* validate transfer in the host */
+	__u32 target;
+	__u32 format;
+	__u32 bind;
+	__u32 width;
+	__u32 height;
+	__u32 depth;
+	__u32 array_size;
+	__u32 last_level;
+	__u32 nr_samples;
+	__u32 flags;
+	__u32 bo_handle; /* if this is set - recreate a new resource attached to this bo ? */
+	__u32 res_handle;  /* returned by kernel */
+	__u32 size;        /* validate transfer in the host */
+	__u32 stride;      /* validate transfer in the host */
 };
 
 struct drm_virtgpu_resource_info {
-	uint32_t bo_handle;
-	uint32_t res_handle;
-	uint32_t size;
-	uint32_t stride;
+	__u32 bo_handle;
+	__u32 res_handle;
+	__u32 size;
+	__u32 stride;
 };
 
 struct drm_virtgpu_3d_box {
-	uint32_t x;
-	uint32_t y;
-	uint32_t z;
-	uint32_t w;
-	uint32_t h;
-	uint32_t d;
+	__u32 x;
+	__u32 y;
+	__u32 z;
+	__u32 w;
+	__u32 h;
+	__u32 d;
 };
 
 struct drm_virtgpu_3d_transfer_to_host {
-	uint32_t bo_handle;
+	__u32 bo_handle;
 	struct drm_virtgpu_3d_box box;
-	uint32_t level;
-	uint32_t offset;
+	__u32 level;
+	__u32 offset;
 };
 
 struct drm_virtgpu_3d_transfer_from_host {
-	uint32_t bo_handle;
+	__u32 bo_handle;
 	struct drm_virtgpu_3d_box box;
-	uint32_t level;
-	uint32_t offset;
+	__u32 level;
+	__u32 offset;
 };
 
 #define VIRTGPU_WAIT_NOWAIT 1 /* like it */
 struct drm_virtgpu_3d_wait {
-	uint32_t handle; /* 0 is an invalid handle */
-	uint32_t flags;
+	__u32 handle; /* 0 is an invalid handle */
+	__u32 flags;
 };
 
 struct drm_virtgpu_get_caps {
-	uint32_t cap_set_id;
-	uint32_t cap_set_ver;
-	uint64_t addr;
-	uint32_t size;
-	uint32_t pad;
+	__u32 cap_set_id;
+	__u32 cap_set_ver;
+	__u64 addr;
+	__u32 size;
+	__u32 pad;
 };
 
 #define DRM_IOCTL_VIRTGPU_MAP \
@@ -30,7 +30,7 @@
  * subject to backwards-compatibility constraints.
  *
- * Do not use pointers, use uint64_t instead for 32 bit / 64 bit user/kernel
+ * Do not use pointers, use __u64 instead for 32 bit / 64 bit user/kernel
  * compatibility Keep fields aligned to their size
  */
-- 
2.6.2

_______________________________________________
dri-devel mailing list
dri-devel@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/dri-devel

       reply	other threads:[~2015-11-30 14:11 UTC|newest]

Thread overview: 26+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
     [not found] <1448892658-14256-1-git-send-email-gabriel@lse.epita.fr>
2015-11-30 14:10 ` Gabriel Laskar [this message]
     [not found]   ` <1448892658-14256-2-git-send-email-gabriel-tU7rkvAWjlwhT4uAktR2oQ@public.gmane.org>
2015-12-04 14:22     ` [PATCH 01/20] drm: use __u{32,64} instead of uint{32,64}_t in virtgpu_drm.h Emil Velikov
2015-12-05 21:03       ` [PATCH 01/20] drm: use __u{32, 64} instead of uint{32, 64}_t " Dave Airlie
     [not found]         ` <CAPM=9tw1Un5-fZUzYGzXLhVikEHj9gw1FfBDc=YMD7xeeKxS9Q-JsoAwUIsXosN+BqQ9rBEUg@public.gmane.org>
2015-12-07 13:29           ` [PATCH 01/20] drm: use __u{32,64} instead of uint{32,64}_t " Emil Velikov
2015-12-07 13:45             ` Mikko Rapeli
2015-12-09 13:56             ` Gabriel Laskar
2015-11-30 14:10 ` [PATCH 02/20] drm: Kbuild: add admgpu_drm.h to the installed headers Gabriel Laskar
     [not found]   ` <1448892658-14256-3-git-send-email-gabriel-tU7rkvAWjlwhT4uAktR2oQ@public.gmane.org>
2015-11-30 23:57     ` Alex Deucher
2015-11-30 14:10 ` [PATCH 03/20] drm: include drm.h in armada_drm.h Gabriel Laskar
2015-11-30 14:10 ` [PATCH 04/20] drm: drm_fourcc.h fix includes Gabriel Laskar
2015-11-30 14:10 ` [PATCH 05/20] drm: drm_mode.h " Gabriel Laskar
2015-11-30 14:10 ` [PATCH 06/20] drm: fix inclusion of drm.h in drm_sarea.h Gabriel Laskar
2015-11-30 14:10 ` [PATCH 07/20] drm: fix inclusion of drm.h in exynos_sarea.h Gabriel Laskar
2015-11-30 14:10 ` [PATCH 08/20] drm: fix inclusion of drm.h in i810_drm.h Gabriel Laskar
2015-11-30 14:10 ` [PATCH 09/20] drm: fix inclusion of drm.h in exynos_sarea.h Gabriel Laskar
2015-11-30 14:10 ` [PATCH 10/20] drm: fix inclusion of drm.h in mga_drm.h Gabriel Laskar
2015-11-30 14:10 ` [PATCH 11/20] drm: fix inclusion of drm.h in msm_drm.h Gabriel Laskar
2015-11-30 14:10 ` [PATCH 12/20] drm: fix inclusion of drm.h in omap_drm.h Gabriel Laskar
2015-11-30 14:10 ` [PATCH 13/20] drm: fix inclusion of drm.h in qxl_drm.h Gabriel Laskar
2015-11-30 14:10 ` [PATCH 14/20] drm: fix inclusion of drm.h in r128_drm.h Gabriel Laskar
2015-11-30 14:10 ` [PATCH 15/20] drm: fix inclusion of drm.h in savage_drm.h Gabriel Laskar
2015-11-30 14:10 ` [PATCH 16/20] drm: fix inclusion of drm.h in tegra_drm.h Gabriel Laskar
2015-11-30 14:10 ` [PATCH 17/20] drm: fix inclusion of drm.h in virtgpu_drm.h Gabriel Laskar
2015-11-30 14:10 ` [PATCH 18/20] drm: fix inclusion of drm.h in vmwgfx_drm.h Gabriel Laskar
2015-11-30 14:10 ` [PATCH 19/20] drm: fix inclusion of drm.h in via_drm.h Gabriel Laskar
2015-11-30 14:10 ` [PATCH 20/20] drm: via: remove userland header Gabriel Laskar

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1448892658-14256-2-git-send-email-gabriel@lse.epita.fr \
    --to=gabriel@lse.epita.fr \
    --cc=airlied@linux.ie \
    --cc=dri-devel@lists.freedesktop.org \
    --cc=emil.l.velikov@gmail.com \
    --cc=linux-api@vger.kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=mikko.rapeli@iki.fi \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).